@@ -60,6 +60,10 @@ class _BaseClient(object):
         self.conf.enable_gzip = enable_gzip
         self.conf.verify_ssl = kwargs.get('verify_ssl', True)
         self.conf.ssl_ca_cert = kwargs.get('ssl_ca_cert', None)
+        self.conf.cert_file = kwargs.get('cert_file', None)
+        self.conf.cert_key_file = kwargs.get('cert_key_file', None)
+        self.conf.cert_key_password = kwargs.get('cert_key_password', None)
+        self.conf.ssl_context = kwargs.get('ssl_context', None)
         self.conf.proxy = kwargs.get('proxy', None)
         self.conf.proxy_headers = kwargs.get('proxy_headers', None)
         self.conf.connection_pool_maxsize = kwargs.get('connection_pool_maxsize', self.conf.connection_pool_maxsize)
@@ -94,15 +98,8 @@ class _BaseClient(object):
         self.profilers = kwargs.get('profilers', None)
         pass
 
-    def _version(self, response) -> str:
-        if response is not None and len(response) >= 3:
-            if 'X-Influxdb-Version' in response[2]:
-                return response[2]['X-Influxdb-Version']
-
-        return "unknown"
-
     @classmethod
-    def _from_config_file(cls, config_file: str = "config.ini", debug=None, enable_gzip=False):
+    def _from_config_file(cls, config_file: str = "config.ini", debug=None, enable_gzip=False, **kwargs):
         config = configparser.ConfigParser()
         is_json = False
         try:
@@ -142,6 +139,18 @@ class _BaseClient(object):
         if _has_option('ssl_ca_cert'):
             ssl_ca_cert = _config_value('ssl_ca_cert')
 
+        cert_file = None
+        if _has_option('cert_file'):
+            cert_file = _config_value('cert_file')
+
+        cert_key_file = None
+        if _has_option('cert_key_file'):
+            cert_key_file = _config_value('cert_key_file')
+
+        cert_key_password = None
+        if _has_option('cert_key_password'):
+            cert_key_password = _config_value('cert_key_password')
+
         connection_pool_maxsize = None
         if _has_option('connection_pool_maxsize'):
             connection_pool_maxsize = _config_value('connection_pool_maxsize')
@@ -168,17 +177,21 @@ class _BaseClient(object):
 
         return cls(url, token, debug=debug, timeout=_to_int(timeout), org=org, default_tags=default_tags,
                    enable_gzip=enable_gzip, verify_ssl=_to_bool(verify_ssl), ssl_ca_cert=ssl_ca_cert,
+                   cert_file=cert_file, cert_key_file=cert_key_file, cert_key_password=cert_key_password,
                    connection_pool_maxsize=_to_int(connection_pool_maxsize), auth_basic=_to_bool(auth_basic),
-                   profilers=profilers, proxy=proxy)
+                   profilers=profilers, proxy=proxy, **kwargs)
 
     @classmethod
-    def _from_env_properties(cls, debug=None, enable_gzip=False):
+    def _from_env_properties(cls, debug=None, enable_gzip=False, **kwargs):
         url = os.getenv('INFLUXDB_V2_URL', "http://localhost:8086")
         token = os.getenv('INFLUXDB_V2_TOKEN', "my-token")
         timeout = os.getenv('INFLUXDB_V2_TIMEOUT', "10000")
         org = os.getenv('INFLUXDB_V2_ORG', "my-org")
         verify_ssl = os.getenv('INFLUXDB_V2_VERIFY_SSL', "True")
         ssl_ca_cert = os.getenv('INFLUXDB_V2_SSL_CA_CERT', None)
+        cert_file = os.getenv('INFLUXDB_V2_CERT_FILE', None)
+        cert_key_file = os.getenv('INFLUXDB_V2_CERT_KEY_FILE', None)
+        cert_key_password = os.getenv('INFLUXDB_V2_CERT_KEY_PASSWORD', None)
         connection_pool_maxsize = os.getenv('INFLUXDB_V2_CONNECTION_POOL_MAXSIZE', None)
         auth_basic = os.getenv('INFLUXDB_V2_AUTH_BASIC', "False")
 
@@ -195,8 +208,9 @@ class _BaseClient(object):
 
         return cls(url, token, debug=debug, timeout=_to_int(timeout), org=org, default_tags=default_tags,
                    enable_gzip=enable_gzip, verify_ssl=_to_bool(verify_ssl), ssl_ca_cert=ssl_ca_cert,
+                   cert_file=cert_file, cert_key_file=cert_key_file, cert_key_password=cert_key_password,
                    connection_pool_maxsize=_to_int(connection_pool_maxsize), auth_basic=_to_bool(auth_basic),
-                   profilers=profilers)
+                   profilers=profilers, **kwargs)
 
 
 # noinspection PyMethodMayBeStatic
