@@ -3,6 +3,7 @@
 # coding: utf-8
 import logging
 import os
+import warnings
 from collections import defaultdict
 from datetime import timedelta
 from enum import Enum
@@ -10,10 +11,10 @@ from random import random
 from time import sleep
 from typing import Union, Any, Iterable, NamedTuple
 
-import rx
-from rx import operators as ops, Observable
-from rx.scheduler import ThreadPoolScheduler
-from rx.subject import Subject
+import reactivex as rx
+from reactivex import operators as ops, Observable
+from reactivex.scheduler import ThreadPoolScheduler
+from reactivex.subject import Subject
 
 from influxdb_client import WritePrecision
 from influxdb_client.client._base import _BaseWriteApi, _HAS_DATACLASS
@@ -56,10 +57,11 @@ class WriteOptions(object):
 
         :param write_type: methods of write (batching, asynchronous, synchronous)
         :param batch_size: the number of data point to collect in batch
-        :param flush_interval: flush data at least in this interval
+        :param flush_interval: flush data at least in this interval (milliseconds)
         :param jitter_interval: this is primarily to avoid large write spikes for users running a large number of
-               client instances ie, a jitter of 5s and flush duration 10s means flushes will happen every 10-15s.
-        :param retry_interval: the time to wait before retry unsuccessful write
+               client instances ie, a jitter of 5s and flush duration 10s means flushes will happen every 10-15s
+               (milliseconds)
+        :param retry_interval: the time to wait before retry unsuccessful write (milliseconds)
         :param max_retries: the number of max retries when write fails, 0 means retry is disabled
         :param max_retry_delay: the maximum delay between each retry attempt in milliseconds
         :param max_retry_time: total timeout for all retry attempts in milliseconds, if 0 retry is disabled
@@ -273,6 +275,14 @@ class WriteApi(_BaseWriteApi):
             self._subject = None
             self._disposable = None
 
+        if self._write_options.write_type is WriteType.asynchronous:
+            message = """The 'WriteType.asynchronous' is deprecated and will be removed in future major version.
+
+You can use native asynchronous version of the client:
+- https://influxdb-client.readthedocs.io/en/stable/usage.html#how-to-use-asyncio
+        """
+            warnings.warn(message, DeprecationWarning)
+
     def write(self, bucket: str, org: str = None,
               record: Union[
                   str, Iterable['str'], Point, Iterable['Point'], dict, Iterable['dict'], bytes, Iterable['bytes'],
